@@ -5,4 +5,4 @@ A dummy class for testing Notify infraestructure
 """
 from .dummy import Dummy
 
-__all__ = ['Dummy']
+__all__ = ('Dummy', )
