@@ -5,15 +5,14 @@ Dummy.
 from typing import Any, Union
 from collections.abc import Callable
 from navconfig.logging import logging
-from notify.utils import colors, Msg
+from notify.utils import Msg
 from notify.models import Actor
 from notify.providers.abstract import ProviderBase, ProviderType
 
 
 def dummy_sent(obj: ProviderBase, recipient: Actor, message: Union[str, Any], result: Any, **kwargs): # pylint: disable=W0613
-    print('RECEIVED ', obj, 'REC: ', recipient, 'MSG: ', message, 'RESULT: ', result, 'OT: ', kwargs)
     logging.debug(f'Message Sent! {recipient!s}')
-    Msg(str(message))
+    #
 
 
 class Dummy(ProviderBase):
@@ -33,7 +32,7 @@ class Dummy(ProviderBase):
     async def close(self):
         print('Closing to Dummy...')
 
-    async def _send_(self, to: Actor, message: Union[str, Any], **kwargs):
+    async def _send_(self, to: Actor, message: Union[str, Any], subject: str = None, **kwargs):
         """
         _send.
 
@@ -41,20 +40,7 @@ class Dummy(ProviderBase):
         """
         msg = await self._render_(to=to, message=message, **kwargs)
         try:
-            level = kwargs['level']
-        except KeyError:
-            level = 'INFO'
-        if level == 'INFO':
-            coloring = colors.bold + colors.fg.green
-        elif level == 'DEBUG':
-            coloring = colors.fg.lightblue
-        elif level == 'WARN':
-            coloring = colors.bold + colors.fg.yellow
-        elif level == 'ERROR':
-            coloring = colors.fg.lightred
-        elif level == 'CRITICAL':
-            coloring = colors.bold + colors.fg.red
-        else:
-            coloring = colors.reset
-        print(coloring + str(msg), colors.reset)
+            Msg(str(msg))
+        except TypeError:
+            print(msg)
         return msg
